@@ -38,6 +38,10 @@ func newAdminWorkflowCommands() []cli.Command {
 			Aliases: []string{"show"},
 			Usage:   "show workflow history from database",
 			Flags: []cli.Flag{
+				cli.StringFlag{
+					Name:  FlagNamespaceID,
+					Usage: "Namespace Id",
+				},
 				cli.StringFlag{
 					Name:  FlagWorkflowIDWithAlias,
 					Usage: "WorkflowId",
@@ -94,6 +98,10 @@ func newAdminWorkflowCommands() []cli.Command {
 			Aliases: []string{"rt"},
 			Usage:   "Refreshes all the tasks of a workflow",
 			Flags: []cli.Flag{
+				cli.StringFlag{
+					Name:  FlagNamespaceID,
+					Usage: "Namespace Id",
+				},
 				cli.StringFlag{
 					Name:  FlagWorkflowIDWithAlias,
 					Usage: "WorkflowId",
@@ -111,8 +119,7 @@ func newAdminWorkflowCommands() []cli.Command {
 			Name:    "delete",
 			Aliases: []string{"del"},
 			Usage:   "Delete current workflow execution and the mutableState record",
-			Flags: append(
-				getDBAndESFlags(),
+			Flags: []cli.Flag{
 				cli.StringFlag{
 					Name:  FlagWorkflowIDWithAlias,
 					Usage: "WorkflowId",
@@ -122,9 +129,10 @@ func newAdminWorkflowCommands() []cli.Command {
 					Usage: "RunId",
 				},
 				cli.BoolFlag{
-					Name:  FlagSkipErrorModeWithAlias,
-					Usage: "skip errors",
-				}),
+					Name:  FlagYes,
+					Usage: "Optional flag to disable confirmation prompt",
+				},
+			},
 			Action: func(c *cli.Context) {
 				AdminDeleteWorkflow(c)
 			},
