@@ -244,6 +244,22 @@ const (
 	FlagPort                                  = "port"
 	FlagConnectionEnable                      = "enable_connection"
 	FlagConnectionEnableWithAlias             = FlagConnectionEnable + ", ec"
+	FlagScheduleID                            = "schedule_id"
+	FlagScheduleIDWithAlias                   = FlagScheduleID + ", sid, s"
+	FlagOverlapPolicy                         = "overlap_policy"
+	FlagCalendar                              = "calendar"
+	FlagInterval                              = "interval"
+	FlagStartTime                             = "start_time"
+	FlagEndTime                               = "end_time"
+	FlagJitter                                = "jitter"
+	FlagTimeZone                              = "time_zone"
+	FlagNotes                                 = "notes"
+	FlagPauseOnFailure                        = "pause_on_failure"
+	FlagPause                                 = "pause"
+	FlagUnpause                               = "unpause"
+	FlagRemainingActions                      = "remaining_actions"
+	FlagCatchupWindow                         = "catchup_window"
+	FlagSearchAttribute                       = "search_attribute"
 
 	FlagProtoType  = "type"
 	FlagHexData    = "hex_data"
